# artdep

## About
This is a Python package designed by the Marianski Lab to easily create and design figures for publication. The package can generate a variety of different plots for data analysis such as scatterplots, MD trajectories, free energy maps, histograms, etc. Currently our package supports importing data by parsing log files from Gaussian 16, Gromacs, ORCA and CP2K.

Documentation for this project can be found [here](https://marianski-lab.github.io/artdep/index.html)   
Examples on how to use the functions in this project can be found [here](https://drive.google.com/drive/folders/1JmUZs-CdwWdPFBqxfvrcarnWGhy6zi9g?usp=sharing)

Documentation for the colors can be found [here](https://pratiman-91.github.io/colormaps/docs/Sequential)

## Dependencies
You need the following python packages to use this package:  

Python >= 3.12  

Numpy  
Matplotlib  
Colormaps  
Networkx

## Install Instructions
To install the package you can run  
```
pip install artdep
```

To update the package:
```
pip install artdep --upgrade
```
